@@ -17,6 +17,7 @@ from deatool.MMODEL.malmquist_ccr import MalmCCR
 from deatool.MMODEL.malmquist_sbm import MalmSBM
 from deatool.visualization.Ui_table import Ui_Dialog
 import pandas as pd
+from numpy import nan
 # sys.path.append(os.path.dirname(os.path.realpath(__file__)))
 path = os.path.dirname(os.path.realpath(__file__))
 
@@ -115,6 +116,7 @@ class Tables(QDialog, Ui_Dialog):
             dd = self.comboBox_2.currentText()
             sdd = self.comboBox_6.currentText()
             self.printf('正在计算结果，请稍后')
+            
             if self.tabWidget.currentIndex() == 0:
                 self.input_cols = list(self.df.columns.values[1:int(self.lineEdit.text())+1])
                 self.output_cols = list(self.df.columns.values[int(self.lineEdit.text())+1:int(self.lineEdit.text())+int(self.lineEdit_2.text())+1])
@@ -227,8 +229,19 @@ class Tables(QDialog, Ui_Dialog):
     
     def save(self):
         path = os.path.split(path_openfile_name)[0]
-        self.res.to_excel(path+r'\结果_{}.xlsx'.format(self.key), index=False)
-        pip
+        row = len(self.res.index)
+        if self.tabWidget.currentIndex() == 0:
+            self.res.loc[row] = nan
+            self.res.iloc[row,0] = '该结果通过Deatool计算生成，模型为{}'.format(self.key)
+            self.res.to_excel(path+r'\结果_{}.xlsx'.format(self.key), index=False)
+        elif self.tabWidget.currentIndex() == 1:
+            self.res.loc[row] = nan
+            self.res.iloc[row,0] = '该结果通过Deatool计算生成，模型为{}'.format(self.skey)
+            self.res.to_excel(path+r'\结果_{}.xlsx'.format(self.skey), index=False)
+        elif self.tabWidget.currentIndex() == 2:
+            self.res.loc[row] = nan
+            self.res.iloc[row,0] = '该结果通过Deatool计算生成，模型为{}'.format(self.mkey)
+            self.res.to_excel(path+r'\结果_{}.xlsx'.format(self.mkey), index=False)
 # 运行界面
     def printf(self, mes):
         self.textBrowser.append(mes)  # 在指定的区域显示提示信息
